#!/bin/bash
#
# Create CA Intermediate
# 
# 
# This function will generate a CA Intermediate
# IN: UNIQ_ID_CA, SERIAL
#
PARAM1=$1
PARAM2=$2

usage() {
  echo
  echo "Generate a new certificate"
  echo
  echo "This program will generate a new certificate authority intermediate"
  echo "Requires the file ca-i.pem that is used to sign the certificates"
  echo "The script requires a CA Intermediate certificate used to sign the client"
  echo ""
  echo ""
  echo ""
  echo
  echo "Generate a new certificate"
  echo "  usage:   gen_server.sh  <CA Intermediate> <Org URL> <Serial>"
  echo
  echo "  example: gen_server.sh  ca_i_skunkworks.acme.xyz_10001.crt.pem \\"
  echo "                          skunkworks.acme.xyz \\"
  echo "                          10052 \\"
  echo
  exit 1
}


generate_client() {
  echo_block "Generate Client Certificates  (${UNIQ_ID})"
  # params
  UNIQ_ID=$1
  UNIQ_ID_CA=$2
  SERIAL=$3

  openssl genrsa -out "client_${UNIQ_ID}.keys.pem" 4096

  openssl req -new -key "client_${UNIQ_ID}.keys.pem" \
              -subj "/C=OO/O=ACME/OU=ACME Standard/CN=client_${UNIQ_ID}" \
              -out "client_${UNIQ_ID}.csr.pem"
  # Intermediate signs Client
  openssl x509 -req -days 365 \
               -CA "ca_i_${UNIQ_ID_CA}.crt.pem" -CAkey "ca_i_${UNIQ_ID_CA}.keys.pem" -set_serial ${SERIAL} \
               -in "client_${UNIQ_ID}.csr.pem" -out "client_${UNIQ_ID}.crt.pem"

  # Package the Certificates
  openssl pkcs12 -export -password "pass:password" -inkey "client_${UNIQ_ID}.keys.pem" \
                 -name "Client ${UNIQ_ID} VPN Certificate" -certfile "ca_cert-chain_${UNIQ_ID_CA}.crts.pem" -caname "client_${UNIQ_ID}@acme.xyz" \
                 -in "client_${UNIQ_ID}.crt.pem" -out "client_${UNIQ_ID}.p12"

  # verify certificate (output to text file for review)
  openssl x509 -noout -text -in "client_${UNIQ_ID}.crt.pem" > "client_${UNIQ_ID}.info.txt"
}
